#ifndef __MODULR_COLOUR_SCHEME_READER__
#define __MODULR_COLOUR_SCHEME_READER__

#include "colourschemelabels.h"
#include "defaultColourScheme.h"

class ColourSchemeReader
{

private:

	String colourID[bigLevelMeterBackground+1];


	// Parses tracktions settings file and returns true is successful.
	bool parse (const XmlElement* userSettings)
	{
		XmlElement* setting = userSettings->getFirstChildElement();

		for (int i = 0; i < userSettings->getNumChildElements(); i++)
		{
			if ( setting->hasTagName("SETTING") && setting->compareAttribute("name","colourScheme2.1") )
			{
				XmlElement* colours = setting->getFirstChildElement();
				XmlElement* colour  = colours->getFirstChildElement();

				for (int i = 0; i < colours->getNumChildElements(); i++) 
				{
					colourID[i] = colour->getStringAttribute("colour");
					colour = colour->getNextElement();
				}
				return true;
				break;
			}
			else
			{
				setting = setting->getNextElement();
			}
		}
		return false;
	}



public:	

	ColourSchemeReader()
	{ 
	}


	~ColourSchemeReader()
	{
		clearSingletonInstance();
	}


	void initialize()
	{
		// Default Scheme has been coverted into a binary data
		// to read in case tracktion settings isn't found.
		const char* defaultColourSchemeData;		
		defaultColourSchemeData = defaultColourScheme::currentusersettings_trksettings;

		// Handle Path related information starting here
		String currentUserSettingsPath;
		File   currentUserSettingsFile;

#ifdef JUCE_WIN32
		currentUserSettingsFile = File::getCurrentApplicationFile().getSiblingFile(T("CurrentUserSettings.trksettings"));
#else
		currentUserSettingsPath = T("~/Library/Caches/Tracktion/CurrentUserSettings.trksettings");
		currentUserSettingsFile =  File( currentUserSettingsPath );
#endif
		
		XmlElement* userSettings;

		// If we've found the tracktion settings, parse it, otherwise parse the stored default.
		if ( currentUserSettingsFile.existsAsFile() )
		{
			XmlDocument colourSchemeFile( currentUserSettingsFile );
			userSettings = colourSchemeFile.getDocumentElement();
		}
		else
		{
			XmlDocument colourSchemeFile( defaultColourSchemeData );
			userSettings = colourSchemeFile.getDocumentElement();
		}

		// a bit of a haX0rz here... but T1 has no colourschemes in the settings file, so this
		// catches such conditions and loads the default.  It's late, I'm not thinking clear.
		if (!parse(userSettings))
		{
			XmlDocument colourSchemeFile( defaultColourSchemeData );
			userSettings = colourSchemeFile.getDocumentElement();
			parse(userSettings);
		}
	}


	// call this from your code, and supply it with a colourscheme property descriptor
	// (the enumerations in ColourSchemeLabels.h)
	uint32 getColour(int index)
	{
		return (uint32)colourID[index].getHexValue();
	}

	juce_DeclareSingleton(ColourSchemeReader,false);

};

#endif