//===============================================================================
// Graohical User Interface for your JUCEVST Plugin.
//===============================================================================

#include "colourschemereader.h"
juce_ImplementSingleton(ColourSchemeReader);

#include "JuceVstLookAndFeel.h"
class EditorComponent   : public Component,
                          //public ChangeListener,
						  public ActionBroadcaster

{


	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	// Chunk data structure - store whatever you want to be recalled here
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	struct chunkData
	{
		int  width;
		int  height;
		char data[4096];
	};
	chunkData   chunk;
    MemoryBlock chunkMemory;


    ResizerComponent*   resizer;
	TextEditor*         textEditor;
	

	ColourSchemeReader* userColourScheme;
	Colour              backgroundColour,
		                selectionColour,
		                textboxColour, 
						textColour;


	TrackPadLookAndFeel* trackPadLookAndFeel;


public:
	EditorComponent()
    {
		userColourScheme = ColourSchemeReader::getInstance();
		userColourScheme->initialize();
		
		setWantsKeyboardFocus( false );
		backgroundColour = Colour( userColourScheme->getColour(vstWindowTitleBar) );
		selectionColour  = Colour( userColourScheme->getColour(mediaListHighlight) );
		textboxColour    = Colour( userColourScheme->getColour(projectListBackground) );
		textColour       = Colour( userColourScheme->getColour(projectListText) );

		addAndMakeVisible( textEditor = new TextEditor( T("TrackPad") ) );
		textEditor->setBounds(0,0,250,200 - 20);
		textEditor->setMultiLine(true);
		textEditor->setReturnKeyStartsNewLine(true);
		textEditor->setColours(textColour,textboxColour,selectionColour);

		trackPadLookAndFeel = new TrackPadLookAndFeel();
		textEditor->setLookAndFeel(trackPadLookAndFeel);


		addAndMakeVisible ( resizer = new ResizerComponent(this) );
        setSize (250, 200);
	}

    ~EditorComponent()
    {
		ColourSchemeReader::deleteInstance();
    }

    void paint (Graphics& g)
    {
        g.fillAll (backgroundColour);
    }


	void getStateInformation (MemoryBlock& destData)
	{
		String s;
		s = textEditor->getText();
		s.copyToBuffer(chunk.data,4096);
		
		chunk.width  = getWidth();
		chunk.height = getHeight();

		destData.setSize(0);
		destData.append(&chunk,sizeof(chunk));
	}

	void setStateInformation (const void* data, int sizeInBytes)
	{
		if (   (sizeInBytes == sizeof(chunk)) && (data != 0)   ) 
		{

			// assign chunk to pointer (the stored data) received from host
			chunk = *((chunkData*)data);
			
			String s;
			s.append(chunk.data,4096);
			
			setSize(chunk.width,chunk.height);
			resized();
			
			textEditor->setText(s);
		}	
	}



    void resized()
    {
        resizer->setBounds (getWidth() - 16, getHeight() - 16, 16, 16);
		textEditor->setBounds(0,0,getWidth(),getHeight()-20);
    }

    void changeListenerCallback (void* changedObject)
    {
    }


    void handleCommandMessage (int commandId)
    {
        switch (commandId)
		{
		}
    }

	void setEditorParameter(int index, float value)
	{
	}

};